@@ -115,8 +115,11 @@ class PostRequest:
         new_env.update(kwargs)
         if 'files' in self.request_kwargs:
             for key, file in self.request_kwargs['files'].items():
-                file[1].seek(0) # flip byte stream for subsequent reads
+                file[1].seek(0)  # flip byte stream for subsequent reads
         formatted_kwargs = format_object(self.request_kwargs, new_env)
+        if 'variables' in kwargs.keys():  # directly changing graphql variables if there is a method argument
+            if kwargs['variables'] is not None:  # format: your_method(variables=your_data)
+                formatted_kwargs['json']['variables'] = kwargs['variables']
         return requests.request(**formatted_kwargs)
 
     def set_files(self, data):
